==> haskell-tasty-rerun-1.1.19-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-rerun
version:              1.1.19
visibility:           public
id:                   tasty-rerun-1.1.19-LfUFfAatSspKu3XXvCTnWf
key:                  tasty-rerun-1.1.19-LfUFfAatSspKu3XXvCTnWf
license:              BSD-3-Clause
copyright:
    Oliver Charles (c) 2014,
    Andrew Lelechenko (c) 2019

maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-rerun
synopsis:             Rerun only tests which failed in a previous test run
description:
    This ingredient
    for the <https://hackage.haskell.org/package/tasty tasty> testing framework
    allows filtering a test tree depending
    on the outcome of the previous run.
    This may be useful in many scenarios,
    especially when a test suite grows large.

category:             Testing
abi:                  d180ea63ac8994a2162f981ccc8d9e67
exposed:              True
exposed-modules:      Test.Tasty.Ingredients.Rerun
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-rerun-1.1.19
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-rerun-1.1.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-rerun
hs-libraries:         HStasty-rerun-1.1.19-LfUFfAatSspKu3XXvCTnWf
depends:
    base-4.16.4.0 containers-0.6.5.1 mtl-2.2.2
    optparse-applicative-0.17.1.0-Jx8WaQbsFK9BJBRr9ePa2T
    split-0.2.5-JS5qRudix9E7zRZyecxDAF stm-2.5.0.2
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
    tasty-1.4.3-B04wakHanaTFmtNBHSmYAO transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html:         /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-rerun-1.1.19-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-rerun
version:              1.1.19
visibility:           public
id:                   tasty-rerun-1.1.19-Hc9NPBdxbH2xcHE2Yl9Gj
key:                  tasty-rerun-1.1.19-Hc9NPBdxbH2xcHE2Yl9Gj
license:              BSD-3-Clause
copyright:
    Oliver Charles (c) 2014,
    Andrew Lelechenko (c) 2019

maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-rerun
synopsis:             Rerun only tests which failed in a previous test run
description:
    This ingredient
    for the <https://hackage.haskell.org/package/tasty tasty> testing framework
    allows filtering a test tree depending
    on the outcome of the previous run.
    This may be useful in many scenarios,
    especially when a test suite grows large.

category:             Testing
abi:                  b47dea67b25b0865be755d57aaf5e3af
exposed:              True
exposed-modules:      Test.Tasty.Ingredients.Rerun
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-rerun-1.1.19
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-rerun-1.1.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-rerun
hs-libraries:         HStasty-rerun-1.1.19-Hc9NPBdxbH2xcHE2Yl9Gj
depends:
    base-4.16.4.0 containers-0.6.5.1 mtl-2.2.2
    optparse-applicative-0.17.1.0-AgMeQrX7nmlDOnX2xcegDb
    split-0.2.5-1BBFmVDIVmj8cEMN442cHI stm-2.5.0.2
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
    tasty-1.4.3-2gR9WDhWbJHGLAofnQHAx7 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html:         /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
